@@ -21,16 +21,12 @@
    (which it would do because it found this file in $srcdir).  */
 
 #ifdef HAVE_CONFIG_H
-# ifdef CONFIG_BROKETS
-#  include <config.h>
-# else
-#  include "config.h"
-# endif
+# include <config.h>
 #endif
 
 #include <sys/types.h>
 
-#ifdef __STDC__
+#if __STDC__
 # define voidstar void *
 #else
 # define voidstar char *
@@ -459,8 +455,8 @@ void format _((struct obstack *, int, token_data **));
 
 /* File: freeze.c --- frozen state files.  */
 
-void produce_frozen_state _((const char *, const char *));
-void reload_frozen_state _((const char *, const char *));
+void produce_frozen_state _((const char *));
+void reload_frozen_state _((const char *));
 
 /* Debugging the memory allocator.  */
 
